@@ -40,7 +40,7 @@ except NameError:
 
 RE_APPLICATION = r"^([A-Za-z]+/)+v\d+r\d+(p\d+)?"
 RE_JOB_NAME = r"^[a-zA-Z0-9][a-zA-Z0-9_\-]+$"
-RE_OUTPUT_FILE_TYPE = r"^([A-Z][A-Z0-9_]+\.)+(ROOT|.?DST)$"
+RE_OUTPUT_FILE_TYPE = r"^([A-Za-z][A-Za-z0-9_]+\.)+((ROOT|root)|.?(DST|dst))$"
 RE_OPTIONS_FN = r"^\$?[a-zA-Z0-9/\.\-\+\=_]+$"
 RE_INFORM = r"^(?:[a-zA-Z]{3,}|[^@\s]+@[^@\s]+\.[^@\s]+)$"
 
@@ -100,14 +100,14 @@ def parse_yaml(rendered_yaml):
     )
 
     if "defaults" in data1:
-        data1["defaults"].revalidate(
-            Map(
-                {
-                    Optional(k, default=DEFAULT_JOB_VALUES.get(k)): v
-                    for k, v in BASE_JOB_SCHEMA.items()
-                }
-            )
-        )
+        defaults_schema = {}
+        for key, value in BASE_JOB_SCHEMA.items():
+            if isinstance(key, Optional):
+                key = key.key
+            key = Optional(key, default=DEFAULT_JOB_VALUES.get(key))
+            defaults_schema[key] = value
+
+        data1["defaults"].revalidate(Map(defaults_schema))
         defaults = data1.data["defaults"]
         # Remove the defaults data from the snippet
         del data1["defaults"]
@@ -129,19 +129,20 @@ def parse_yaml(rendered_yaml):
         k = k.data
         v = _ordered_dict_to_dict(v.data)
 
+        production_schema = {}
+        for key, value in BASE_JOB_SCHEMA.items():
+            if isinstance(key, Optional):
+                key = key.key
+                production_schema[Optional(key, default=defaults.get(key))] = value
+            elif key in defaults:
+                production_schema[Optional(key, default=defaults[key])] = value
+            else:
+                production_schema[key] = value
+
         data2.update(
             load(
                 yaml.safe_dump({k: v}),
-                MapPattern(
-                    job_name_schema,
-                    Map(
-                        {
-                            Optional(k, default=defaults[k]) if k in defaults else k: v
-                            for k, v in BASE_JOB_SCHEMA.items()
-                        }
-                    ),
-                    minimum_keys=1,
-                ),
+                MapPattern(job_name_schema, Map(production_schema), minimum_keys=1),
             ).data
         )
 
@@ -154,6 +155,7 @@ def validate_yaml(data, repo_root, prod_name):
         for prop in ["output", "options", "inform"]:
             if not isinstance(job_data[prop], list):
                 job_data[prop] = [job_data[prop]]
+        job_data["output"] = [s.upper() for s in job_data["output"]]
 
     # Normalise the options filenames
     for job_data in data.values():
@@ -167,7 +169,7 @@ def validate_yaml(data, repo_root, prod_name):
             if fn_normed.startswith("../"):
                 raise ValueError("{} not found inside {}".format(fn, repo_root))
             if not isfile(join(repo_root, prod_name, fn_normed)):
-                raise FileNotFoundError()
+                raise FileNotFoundError(isfile(join(repo_root, prod_name, fn_normed)))
             normalised_options.append(
                 join("$ANALYSIS_PRODUCTIONS_BASE", prod_name, fn_normed)
             )
